pub struct BatchDocumentItem {
pub key: DocumentKey,
pub document: Option<DocumentResponse>,
}Fields
key: DocumentKeydocument: Option<DocumentResponse>Trait Implementations
Sourceimpl Clone for BatchDocumentItem
impl Clone for BatchDocumentItem
Sourcefn clone(&self) -> BatchDocumentItem
fn clone(&self) -> BatchDocumentItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for BatchDocumentItem
impl ComposeSchema for BatchDocumentItem
Sourceimpl Debug for BatchDocumentItem
impl Debug for BatchDocumentItem
Sourceimpl<'de> Deserialize<'de> for BatchDocumentItem
impl<'de> Deserialize<'de> for BatchDocumentItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchDocumentItem
impl JsonSchema for BatchDocumentItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BatchDocumentItem
impl Serialize for BatchDocumentItem