pub struct BatchGetDocumentsResponse {
pub items: Vec<BatchDocumentItem>,
}Fields
items: Vec<BatchDocumentItem>Trait Implementations
Sourceimpl Clone for BatchGetDocumentsResponse
impl Clone for BatchGetDocumentsResponse
Sourcefn clone(&self) -> BatchGetDocumentsResponse
fn clone(&self) -> BatchGetDocumentsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for BatchGetDocumentsResponse
impl ComposeSchema for BatchGetDocumentsResponse
Sourceimpl Debug for BatchGetDocumentsResponse
impl Debug for BatchGetDocumentsResponse
Sourceimpl<'de> Deserialize<'de> for BatchGetDocumentsResponse
impl<'de> Deserialize<'de> for BatchGetDocumentsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchGetDocumentsResponse
impl JsonSchema for BatchGetDocumentsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BatchGetDocumentsResponse
impl RefUnwindSafe for BatchGetDocumentsResponse
impl Send for BatchGetDocumentsResponse
impl Sync for BatchGetDocumentsResponse
impl Unpin for BatchGetDocumentsResponse
impl UnsafeUnpin for BatchGetDocumentsResponse
impl UnwindSafe for BatchGetDocumentsResponse