pub struct DocumentKey {
pub source_key: String,
pub external_id: String,
}Fields
source_key: Stringexternal_id: StringTrait Implementations
Sourceimpl Clone for DocumentKey
impl Clone for DocumentKey
Sourcefn clone(&self) -> DocumentKey
fn clone(&self) -> DocumentKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentKey
impl ComposeSchema for DocumentKey
Sourceimpl Debug for DocumentKey
impl Debug for DocumentKey
Sourceimpl<'de> Deserialize<'de> for DocumentKey
impl<'de> Deserialize<'de> for DocumentKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentKey
impl JsonSchema for DocumentKey
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentKey
impl Serialize for DocumentKey