pub struct DocumentQueryRequest {
pub source_key: Option<String>,
pub published_after: Option<DateTime<Utc>>,
pub published_before: Option<DateTime<Utc>>,
pub metadata_filters: Vec<MetadataFilter>,
pub sort: Vec<DocumentSort>,
pub limit: usize,
pub cursor: Option<String>,
}Fields
source_key: Option<String>published_after: Option<DateTime<Utc>>published_before: Option<DateTime<Utc>>metadata_filters: Vec<MetadataFilter>sort: Vec<DocumentSort>limit: usizecursor: Option<String>Trait Implementations
Sourceimpl Clone for DocumentQueryRequest
impl Clone for DocumentQueryRequest
Sourcefn clone(&self) -> DocumentQueryRequest
fn clone(&self) -> DocumentQueryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentQueryRequest
impl ComposeSchema for DocumentQueryRequest
Sourceimpl Debug for DocumentQueryRequest
impl Debug for DocumentQueryRequest
Sourceimpl<'de> Deserialize<'de> for DocumentQueryRequest
impl<'de> Deserialize<'de> for DocumentQueryRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentQueryRequest
impl JsonSchema for DocumentQueryRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentQueryRequest
impl Serialize for DocumentQueryRequest