pub struct DocumentQueryResponse {
pub documents: Vec<DocumentResponse>,
pub next_cursor: Option<String>,
}Fields
documents: Vec<DocumentResponse>next_cursor: Option<String>Trait Implementations
Sourceimpl Clone for DocumentQueryResponse
impl Clone for DocumentQueryResponse
Sourcefn clone(&self) -> DocumentQueryResponse
fn clone(&self) -> DocumentQueryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentQueryResponse
impl ComposeSchema for DocumentQueryResponse
Sourceimpl Debug for DocumentQueryResponse
impl Debug for DocumentQueryResponse
Sourceimpl<'de> Deserialize<'de> for DocumentQueryResponse
impl<'de> Deserialize<'de> for DocumentQueryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentQueryResponse
impl JsonSchema for DocumentQueryResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentQueryResponse
impl Serialize for DocumentQueryResponse