pub struct DocumentSort {
pub field: DocumentSortField,
pub order: SortOrder,
}Fields
field: DocumentSortFieldorder: SortOrderTrait Implementations
Sourceimpl Clone for DocumentSort
impl Clone for DocumentSort
Sourcefn clone(&self) -> DocumentSort
fn clone(&self) -> DocumentSort
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentSort
impl ComposeSchema for DocumentSort
Sourceimpl Debug for DocumentSort
impl Debug for DocumentSort
Sourceimpl<'de> Deserialize<'de> for DocumentSort
impl<'de> Deserialize<'de> for DocumentSort
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentSort
impl JsonSchema for DocumentSort
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentSort
impl Serialize for DocumentSort