pub struct MetadataFilter {
pub path: String,
pub operator: MetadataFilterOperator,
pub value: Option<Value>,
pub min: Option<Value>,
pub max: Option<Value>,
}Fields
path: Stringoperator: MetadataFilterOperatorvalue: Option<Value>min: Option<Value>max: Option<Value>Trait Implementations
Sourceimpl Clone for MetadataFilter
impl Clone for MetadataFilter
Sourcefn clone(&self) -> MetadataFilter
fn clone(&self) -> MetadataFilter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for MetadataFilter
impl ComposeSchema for MetadataFilter
Sourceimpl Debug for MetadataFilter
impl Debug for MetadataFilter
Sourceimpl<'de> Deserialize<'de> for MetadataFilter
impl<'de> Deserialize<'de> for MetadataFilter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetadataFilter
impl JsonSchema for MetadataFilter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for MetadataFilter
impl Serialize for MetadataFilter