pub struct MetadataIndexResponse {Show 13 fields
pub index_id: Uuid,
pub group_path: String,
pub source_key: String,
pub path: String,
pub data_type: MetadataDataType,
pub value_kind: MetadataValueKind,
pub sortable: bool,
pub status: MetadataIndexStatus,
pub processed_documents: i64,
pub total_documents: i64,
pub error_message: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
index_id: Uuidgroup_path: Stringsource_key: Stringpath: Stringdata_type: MetadataDataTypevalue_kind: MetadataValueKindsortable: boolstatus: MetadataIndexStatusprocessed_documents: i64total_documents: i64error_message: Option<String>created_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for MetadataIndexResponse
impl Clone for MetadataIndexResponse
Sourcefn clone(&self) -> MetadataIndexResponse
fn clone(&self) -> MetadataIndexResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for MetadataIndexResponse
impl ComposeSchema for MetadataIndexResponse
Sourceimpl Debug for MetadataIndexResponse
impl Debug for MetadataIndexResponse
Sourceimpl<'de> Deserialize<'de> for MetadataIndexResponse
impl<'de> Deserialize<'de> for MetadataIndexResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetadataIndexResponse
impl JsonSchema for MetadataIndexResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for MetadataIndexResponse
impl Serialize for MetadataIndexResponse