pub struct UpdateMetadataIndexRequest {
pub data_type: MetadataDataType,
pub value_kind: MetadataValueKind,
pub sortable: bool,
}Fields
data_type: MetadataDataTypevalue_kind: MetadataValueKindsortable: boolTrait Implementations
Sourceimpl Clone for UpdateMetadataIndexRequest
impl Clone for UpdateMetadataIndexRequest
Sourcefn clone(&self) -> UpdateMetadataIndexRequest
fn clone(&self) -> UpdateMetadataIndexRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateMetadataIndexRequest
impl ComposeSchema for UpdateMetadataIndexRequest
Sourceimpl Debug for UpdateMetadataIndexRequest
impl Debug for UpdateMetadataIndexRequest
Sourceimpl<'de> Deserialize<'de> for UpdateMetadataIndexRequest
impl<'de> Deserialize<'de> for UpdateMetadataIndexRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateMetadataIndexRequest
impl JsonSchema for UpdateMetadataIndexRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateMetadataIndexRequest
impl RefUnwindSafe for UpdateMetadataIndexRequest
impl Send for UpdateMetadataIndexRequest
impl Sync for UpdateMetadataIndexRequest
impl Unpin for UpdateMetadataIndexRequest
impl UnsafeUnpin for UpdateMetadataIndexRequest
impl UnwindSafe for UpdateMetadataIndexRequest