pub struct ExtractionDirective {
pub template_key: String,
pub parameters: Value,
}Fields
template_key: Stringparameters: ValueTrait Implementations
Sourceimpl Clone for ExtractionDirective
impl Clone for ExtractionDirective
Sourcefn clone(&self) -> ExtractionDirective
fn clone(&self) -> ExtractionDirective
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionDirective
impl ComposeSchema for ExtractionDirective
Sourceimpl Debug for ExtractionDirective
impl Debug for ExtractionDirective
Sourceimpl Default for ExtractionDirective
impl Default for ExtractionDirective
Sourcefn default() -> ExtractionDirective
fn default() -> ExtractionDirective
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionDirective
impl<'de> Deserialize<'de> for ExtractionDirective
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractionDirective
impl JsonSchema for ExtractionDirective
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionDirective
impl PartialEq for ExtractionDirective
Sourceimpl Serialize for ExtractionDirective
impl Serialize for ExtractionDirective
impl StructuralPartialEq for ExtractionDirective