pub struct ExtractionJobsResponse {
pub jobs: Vec<ExtractionJobResponse>,
pub latest_results: Vec<ExtractionResultResponse>,
}Fields
jobs: Vec<ExtractionJobResponse>latest_results: Vec<ExtractionResultResponse>Trait Implementations
Sourceimpl Clone for ExtractionJobsResponse
impl Clone for ExtractionJobsResponse
Sourcefn clone(&self) -> ExtractionJobsResponse
fn clone(&self) -> ExtractionJobsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionJobsResponse
impl ComposeSchema for ExtractionJobsResponse
Sourceimpl Debug for ExtractionJobsResponse
impl Debug for ExtractionJobsResponse
Sourceimpl<'de> Deserialize<'de> for ExtractionJobsResponse
impl<'de> Deserialize<'de> for ExtractionJobsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractionJobsResponse
impl JsonSchema for ExtractionJobsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ExtractionJobsResponse
impl Serialize for ExtractionJobsResponse