pub struct ExtractionTemplateInput {
pub template_key: String,
pub description: Option<String>,
pub system_prompt: String,
pub output_schema: Value,
pub max_output_tokens: Option<i32>,
pub enabled: bool,
}Fields
template_key: Stringdescription: Option<String>system_prompt: Stringoutput_schema: Valuemax_output_tokens: Option<i32>enabled: boolTrait Implementations
Sourceimpl Clone for ExtractionTemplateInput
impl Clone for ExtractionTemplateInput
Sourcefn clone(&self) -> ExtractionTemplateInput
fn clone(&self) -> ExtractionTemplateInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionTemplateInput
impl ComposeSchema for ExtractionTemplateInput
Sourceimpl Debug for ExtractionTemplateInput
impl Debug for ExtractionTemplateInput
Sourceimpl<'de> Deserialize<'de> for ExtractionTemplateInput
impl<'de> Deserialize<'de> for ExtractionTemplateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractionTemplateInput
impl JsonSchema for ExtractionTemplateInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ExtractionTemplateInput
impl Serialize for ExtractionTemplateInput