pub struct ExtractionTemplateResponse {
pub template_key: String,
pub version: i32,
pub description: Option<String>,
pub system_prompt: String,
pub output_schema: Value,
pub max_output_tokens: i32,
pub enabled: bool,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
template_key: Stringversion: i32description: Option<String>system_prompt: Stringoutput_schema: Valuemax_output_tokens: i32enabled: boolcreated_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ExtractionTemplateResponse
impl Clone for ExtractionTemplateResponse
Sourcefn clone(&self) -> ExtractionTemplateResponse
fn clone(&self) -> ExtractionTemplateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionTemplateResponse
impl ComposeSchema for ExtractionTemplateResponse
Sourceimpl Debug for ExtractionTemplateResponse
impl Debug for ExtractionTemplateResponse
Sourceimpl<'de> Deserialize<'de> for ExtractionTemplateResponse
impl<'de> Deserialize<'de> for ExtractionTemplateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractionTemplateResponse
impl JsonSchema for ExtractionTemplateResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtractionTemplateResponse
impl RefUnwindSafe for ExtractionTemplateResponse
impl Send for ExtractionTemplateResponse
impl Sync for ExtractionTemplateResponse
impl Unpin for ExtractionTemplateResponse
impl UnsafeUnpin for ExtractionTemplateResponse
impl UnwindSafe for ExtractionTemplateResponse