pub struct RebuildDocumentExtractionsRequest {
pub template_keys: Vec<String>,
}Fields
template_keys: Vec<String>Trait Implementations
Sourceimpl Clone for RebuildDocumentExtractionsRequest
impl Clone for RebuildDocumentExtractionsRequest
Sourcefn clone(&self) -> RebuildDocumentExtractionsRequest
fn clone(&self) -> RebuildDocumentExtractionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RebuildDocumentExtractionsRequest
impl ComposeSchema for RebuildDocumentExtractionsRequest
Sourceimpl<'de> Deserialize<'de> for RebuildDocumentExtractionsRequest
impl<'de> Deserialize<'de> for RebuildDocumentExtractionsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RebuildDocumentExtractionsRequest
impl JsonSchema for RebuildDocumentExtractionsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RebuildDocumentExtractionsRequest
impl RefUnwindSafe for RebuildDocumentExtractionsRequest
impl Send for RebuildDocumentExtractionsRequest
impl Sync for RebuildDocumentExtractionsRequest
impl Unpin for RebuildDocumentExtractionsRequest
impl UnsafeUnpin for RebuildDocumentExtractionsRequest
impl UnwindSafe for RebuildDocumentExtractionsRequest