pub struct McpDocumentQueryResponse {
pub documents: Vec<McpDocumentSummary>,
pub next_cursor: Option<String>,
pub truncated: bool,
pub has_more: bool,
}Fields
documents: Vec<McpDocumentSummary>next_cursor: Option<String>truncated: boolhas_more: boolTrait Implementations
Sourceimpl Clone for McpDocumentQueryResponse
impl Clone for McpDocumentQueryResponse
Sourcefn clone(&self) -> McpDocumentQueryResponse
fn clone(&self) -> McpDocumentQueryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpDocumentQueryResponse
impl Debug for McpDocumentQueryResponse
Sourceimpl<'de> Deserialize<'de> for McpDocumentQueryResponse
impl<'de> Deserialize<'de> for McpDocumentQueryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpDocumentQueryResponse
impl JsonSchema for McpDocumentQueryResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpDocumentQueryResponse
impl RefUnwindSafe for McpDocumentQueryResponse
impl Send for McpDocumentQueryResponse
impl Sync for McpDocumentQueryResponse
impl Unpin for McpDocumentQueryResponse
impl UnsafeUnpin for McpDocumentQueryResponse
impl UnwindSafe for McpDocumentQueryResponse