pub struct McpSearchHit {
pub document_id: i64,
pub external_id: String,
pub title: String,
pub summary: Option<String>,
pub source_uri: String,
pub published_at: Option<DateTime<Utc>>,
pub score: f32,
pub snippet: String,
}Fields
document_id: i64external_id: Stringtitle: Stringsummary: Option<String>source_uri: Stringpublished_at: Option<DateTime<Utc>>score: f32snippet: StringTrait Implementations
Sourceimpl Clone for McpSearchHit
impl Clone for McpSearchHit
Sourcefn clone(&self) -> McpSearchHit
fn clone(&self) -> McpSearchHit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpSearchHit
impl Debug for McpSearchHit
Sourceimpl<'de> Deserialize<'de> for McpSearchHit
impl<'de> Deserialize<'de> for McpSearchHit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpSearchHit
impl JsonSchema for McpSearchHit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpSearchHit
impl RefUnwindSafe for McpSearchHit
impl Send for McpSearchHit
impl Sync for McpSearchHit
impl Unpin for McpSearchHit
impl UnsafeUnpin for McpSearchHit
impl UnwindSafe for McpSearchHit