pub struct McpSourceListResponse {
pub sources: Vec<SourceStatus>,
pub truncated: bool,
pub has_more: bool,
}Fields
sources: Vec<SourceStatus>truncated: boolhas_more: boolTrait Implementations
Sourceimpl Clone for McpSourceListResponse
impl Clone for McpSourceListResponse
Sourcefn clone(&self) -> McpSourceListResponse
fn clone(&self) -> McpSourceListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpSourceListResponse
impl Debug for McpSourceListResponse
Sourceimpl<'de> Deserialize<'de> for McpSourceListResponse
impl<'de> Deserialize<'de> for McpSourceListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpSourceListResponse
impl JsonSchema for McpSourceListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpSourceListResponse
impl RefUnwindSafe for McpSourceListResponse
impl Send for McpSourceListResponse
impl Sync for McpSourceListResponse
impl Unpin for McpSourceListResponse
impl UnsafeUnpin for McpSourceListResponse
impl UnwindSafe for McpSourceListResponse