pub struct SyncOutcome {
pub records_seen: usize,
pub records_changed: usize,
pub chunks_upserted: usize,
}Fields
records_seen: usizerecords_changed: usizechunks_upserted: usizeTrait Implementations
Sourceimpl Clone for SyncOutcome
impl Clone for SyncOutcome
Sourcefn clone(&self) -> SyncOutcome
fn clone(&self) -> SyncOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SyncOutcome
impl ComposeSchema for SyncOutcome
Sourceimpl Debug for SyncOutcome
impl Debug for SyncOutcome
Sourceimpl<'de> Deserialize<'de> for SyncOutcome
impl<'de> Deserialize<'de> for SyncOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncOutcome
impl JsonSchema for SyncOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SyncOutcome
impl Serialize for SyncOutcome