pub struct DocumentChunkResponse {
pub chunk_id: Uuid,
pub chunk_index: i32,
pub text: String,
}Fields
chunk_id: Uuidchunk_index: i32text: StringTrait Implementations
Sourceimpl Clone for DocumentChunkResponse
impl Clone for DocumentChunkResponse
Sourcefn clone(&self) -> DocumentChunkResponse
fn clone(&self) -> DocumentChunkResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentChunkResponse
impl ComposeSchema for DocumentChunkResponse
Sourceimpl Debug for DocumentChunkResponse
impl Debug for DocumentChunkResponse
Sourceimpl<'de> Deserialize<'de> for DocumentChunkResponse
impl<'de> Deserialize<'de> for DocumentChunkResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentChunkResponse
impl JsonSchema for DocumentChunkResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentChunkResponse
impl Serialize for DocumentChunkResponse