pub struct DocumentResponse {Show 18 fields
pub document_id: i64,
pub group_key: String,
pub project_key: String,
pub visibility: Visibility,
pub source_key: String,
pub external_id: String,
pub title: String,
pub summary: Option<String>,
pub source_uri: String,
pub published_at: Option<NaiveDate>,
pub updated_at: DateTime<Utc>,
pub record_hash: String,
pub metadata_json: Value,
pub library_file_id: Option<Uuid>,
pub library_section_label: Option<String>,
pub library_path: Option<String>,
pub is_library_file: bool,
pub chunks: Vec<DocumentChunkResponse>,
}Fields
document_id: i64group_key: Stringproject_key: Stringvisibility: Visibilitysource_key: Stringexternal_id: Stringtitle: Stringsummary: Option<String>source_uri: Stringpublished_at: Option<NaiveDate>updated_at: DateTime<Utc>record_hash: Stringmetadata_json: Valuelibrary_file_id: Option<Uuid>library_section_label: Option<String>library_path: Option<String>is_library_file: boolchunks: Vec<DocumentChunkResponse>Trait Implementations
Sourceimpl Clone for DocumentResponse
impl Clone for DocumentResponse
Sourcefn clone(&self) -> DocumentResponse
fn clone(&self) -> DocumentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentResponse
impl ComposeSchema for DocumentResponse
Sourceimpl Debug for DocumentResponse
impl Debug for DocumentResponse
Sourceimpl<'de> Deserialize<'de> for DocumentResponse
impl<'de> Deserialize<'de> for DocumentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentResponse
impl JsonSchema for DocumentResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for DocumentResponse
impl Serialize for DocumentResponse