pub struct ListSourcesResponse {
pub sources: Vec<SourceStatus>,
}Fields
sources: Vec<SourceStatus>Trait Implementations
Sourceimpl Clone for ListSourcesResponse
impl Clone for ListSourcesResponse
Sourcefn clone(&self) -> ListSourcesResponse
fn clone(&self) -> ListSourcesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSourcesResponse
impl Debug for ListSourcesResponse
Sourceimpl<'de> Deserialize<'de> for ListSourcesResponse
impl<'de> Deserialize<'de> for ListSourcesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListSourcesResponse
impl JsonSchema for ListSourcesResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListSourcesResponse
impl RefUnwindSafe for ListSourcesResponse
impl Send for ListSourcesResponse
impl Sync for ListSourcesResponse
impl Unpin for ListSourcesResponse
impl UnsafeUnpin for ListSourcesResponse
impl UnwindSafe for ListSourcesResponse