pub struct SearchHit {Show 23 fields
pub chunk_id: Uuid,
pub document_id: i64,
pub group_key: String,
pub project_key: String,
pub visibility: Visibility,
pub source_key: String,
pub external_id: String,
pub title: String,
pub summary: Option<String>,
pub source_uri: String,
pub published_at: Option<NaiveDate>,
pub chunk_index: i32,
pub chunk_text: String,
pub score: f32,
pub vector_score: Option<f32>,
pub keyword_score: Option<f32>,
pub rerank_score: Option<f32>,
pub match_reason: Option<String>,
pub metadata_json: Value,
pub library_file_id: Option<Uuid>,
pub library_section_label: Option<String>,
pub library_path: Option<String>,
pub is_library_file: bool,
}Fields
chunk_id: Uuiddocument_id: i64group_key: Stringproject_key: Stringvisibility: Visibilitysource_key: Stringexternal_id: Stringtitle: Stringsummary: Option<String>source_uri: Stringpublished_at: Option<NaiveDate>chunk_index: i32chunk_text: Stringscore: f32vector_score: Option<f32>keyword_score: Option<f32>rerank_score: Option<f32>match_reason: Option<String>metadata_json: Valuelibrary_file_id: Option<Uuid>library_section_label: Option<String>library_path: Option<String>is_library_file: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for SearchHit
impl<'de> Deserialize<'de> for SearchHit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchHit
impl JsonSchema for SearchHit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchHit
impl RefUnwindSafe for SearchHit
impl Send for SearchHit
impl Sync for SearchHit
impl Unpin for SearchHit
impl UnsafeUnpin for SearchHit
impl UnwindSafe for SearchHit