pub struct SearchRequest {
pub query: String,
pub limit: usize,
pub source_key: Option<String>,
pub group_key: Option<String>,
pub project_key: Option<String>,
pub published_after: Option<NaiveDate>,
pub published_before: Option<NaiveDate>,
}Fields
query: Stringlimit: usizesource_key: Option<String>group_key: Option<String>project_key: Option<String>published_after: Option<NaiveDate>published_before: Option<NaiveDate>Trait Implementations
Sourceimpl Clone for SearchRequest
impl Clone for SearchRequest
Sourcefn clone(&self) -> SearchRequest
fn clone(&self) -> SearchRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SearchRequest
impl ComposeSchema for SearchRequest
Sourceimpl Debug for SearchRequest
impl Debug for SearchRequest
Sourceimpl<'de> Deserialize<'de> for SearchRequest
impl<'de> Deserialize<'de> for SearchRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchRequest
impl JsonSchema for SearchRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SearchRequest
impl Serialize for SearchRequest