pub struct CancelActiveTasksResponse {
pub cancelled_tasks: i64,
}Fields
cancelled_tasks: i64Trait Implementations
Sourceimpl Clone for CancelActiveTasksResponse
impl Clone for CancelActiveTasksResponse
Sourcefn clone(&self) -> CancelActiveTasksResponse
fn clone(&self) -> CancelActiveTasksResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CancelActiveTasksResponse
impl ComposeSchema for CancelActiveTasksResponse
Sourceimpl Debug for CancelActiveTasksResponse
impl Debug for CancelActiveTasksResponse
Sourceimpl<'de> Deserialize<'de> for CancelActiveTasksResponse
impl<'de> Deserialize<'de> for CancelActiveTasksResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CancelActiveTasksResponse
impl JsonSchema for CancelActiveTasksResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CancelActiveTasksResponse
impl RefUnwindSafe for CancelActiveTasksResponse
impl Send for CancelActiveTasksResponse
impl Sync for CancelActiveTasksResponse
impl Unpin for CancelActiveTasksResponse
impl UnsafeUnpin for CancelActiveTasksResponse
impl UnwindSafe for CancelActiveTasksResponse