pub struct ExternalJobInfo {
pub provider: String,
pub remote_task_id: String,
pub status: String,
pub remote_status: Option<String>,
pub submitted_at: DateTime<Utc>,
pub last_polled_at: Option<DateTime<Utc>>,
pub next_poll_at: Option<DateTime<Utc>>,
pub deadline_at: Option<DateTime<Utc>>,
pub error_message: Option<String>,
}Fields
provider: Stringremote_task_id: Stringstatus: Stringremote_status: Option<String>submitted_at: DateTime<Utc>last_polled_at: Option<DateTime<Utc>>next_poll_at: Option<DateTime<Utc>>deadline_at: Option<DateTime<Utc>>error_message: Option<String>Trait Implementations
Sourceimpl Clone for ExternalJobInfo
impl Clone for ExternalJobInfo
Sourcefn clone(&self) -> ExternalJobInfo
fn clone(&self) -> ExternalJobInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExternalJobInfo
impl ComposeSchema for ExternalJobInfo
Sourceimpl Debug for ExternalJobInfo
impl Debug for ExternalJobInfo
Sourceimpl<'de> Deserialize<'de> for ExternalJobInfo
impl<'de> Deserialize<'de> for ExternalJobInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExternalJobInfo
impl JsonSchema for ExternalJobInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ExternalJobInfo
impl Serialize for ExternalJobInfo