pub struct ScopeSpec {
pub group_path: String,
pub name: String,
pub visibility: Visibility,
pub kind: Option<GroupKind>,
pub metadata_indexes: Vec<ScopeMetadataIndex>,
}Fields
group_path: Stringname: Stringvisibility: Visibilitykind: Option<GroupKind>metadata_indexes: Vec<ScopeMetadataIndex>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ScopeSpec
impl<'de> Deserialize<'de> for ScopeSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScopeSpec
impl JsonSchema for ScopeSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScopeSpec
impl RefUnwindSafe for ScopeSpec
impl Send for ScopeSpec
impl Sync for ScopeSpec
impl Unpin for ScopeSpec
impl UnsafeUnpin for ScopeSpec
impl UnwindSafe for ScopeSpec