pub struct TaskMaintenanceOverview {
pub settings: TaskMaintenanceSettings,
pub stats: TaskMaintenanceStats,
}Fields
settings: TaskMaintenanceSettingsstats: TaskMaintenanceStatsTrait Implementations
Sourceimpl Clone for TaskMaintenanceOverview
impl Clone for TaskMaintenanceOverview
Sourcefn clone(&self) -> TaskMaintenanceOverview
fn clone(&self) -> TaskMaintenanceOverview
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TaskMaintenanceOverview
impl ComposeSchema for TaskMaintenanceOverview
Sourceimpl Debug for TaskMaintenanceOverview
impl Debug for TaskMaintenanceOverview
Sourceimpl<'de> Deserialize<'de> for TaskMaintenanceOverview
impl<'de> Deserialize<'de> for TaskMaintenanceOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskMaintenanceOverview
impl JsonSchema for TaskMaintenanceOverview
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TaskMaintenanceOverview
impl Serialize for TaskMaintenanceOverview