pub struct TaskMaintenanceSettings {
pub cleanup_enabled: bool,
pub retention_days: i64,
pub updated_at: DateTime<Utc>,
}Fields
cleanup_enabled: boolretention_days: i64updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for TaskMaintenanceSettings
impl Clone for TaskMaintenanceSettings
Sourcefn clone(&self) -> TaskMaintenanceSettings
fn clone(&self) -> TaskMaintenanceSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TaskMaintenanceSettings
impl ComposeSchema for TaskMaintenanceSettings
Sourceimpl Debug for TaskMaintenanceSettings
impl Debug for TaskMaintenanceSettings
Sourceimpl<'de> Deserialize<'de> for TaskMaintenanceSettings
impl<'de> Deserialize<'de> for TaskMaintenanceSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskMaintenanceSettings
impl JsonSchema for TaskMaintenanceSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TaskMaintenanceSettings
impl Serialize for TaskMaintenanceSettings