pub struct TaskMaintenanceStats {
pub total: i64,
pub queued: i64,
pub running: i64,
pub waiting: i64,
pub succeeded: i64,
pub failed: i64,
pub cancelled: i64,
pub active: i64,
pub expired_terminal: i64,
}Fields
total: i64queued: i64running: i64waiting: i64succeeded: i64failed: i64cancelled: i64active: i64expired_terminal: i64Trait Implementations
Sourceimpl Clone for TaskMaintenanceStats
impl Clone for TaskMaintenanceStats
Sourcefn clone(&self) -> TaskMaintenanceStats
fn clone(&self) -> TaskMaintenanceStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TaskMaintenanceStats
impl ComposeSchema for TaskMaintenanceStats
Sourceimpl Debug for TaskMaintenanceStats
impl Debug for TaskMaintenanceStats
Sourceimpl<'de> Deserialize<'de> for TaskMaintenanceStats
impl<'de> Deserialize<'de> for TaskMaintenanceStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskMaintenanceStats
impl JsonSchema for TaskMaintenanceStats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TaskMaintenanceStats
impl Serialize for TaskMaintenanceStats