pub struct TaskProgress {
pub total: i64,
pub queued: i64,
pub running: i64,
pub succeeded: i64,
pub failed: i64,
pub cancelled: i64,
}Fields
total: i64queued: i64running: i64succeeded: i64failed: i64cancelled: i64Trait Implementations
Sourceimpl Clone for TaskProgress
impl Clone for TaskProgress
Sourcefn clone(&self) -> TaskProgress
fn clone(&self) -> TaskProgress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TaskProgress
impl ComposeSchema for TaskProgress
Sourceimpl Debug for TaskProgress
impl Debug for TaskProgress
Sourceimpl<'de> Deserialize<'de> for TaskProgress
impl<'de> Deserialize<'de> for TaskProgress
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskProgress
impl JsonSchema for TaskProgress
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TaskProgress
impl Serialize for TaskProgress