pub struct TaskRetryResponse {
pub task: TaskRef,
pub retried_items: i64,
}Fields
task: TaskRefretried_items: i64Trait Implementations
Sourceimpl Clone for TaskRetryResponse
impl Clone for TaskRetryResponse
Sourcefn clone(&self) -> TaskRetryResponse
fn clone(&self) -> TaskRetryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TaskRetryResponse
impl ComposeSchema for TaskRetryResponse
Sourceimpl Debug for TaskRetryResponse
impl Debug for TaskRetryResponse
Sourceimpl<'de> Deserialize<'de> for TaskRetryResponse
impl<'de> Deserialize<'de> for TaskRetryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskRetryResponse
impl JsonSchema for TaskRetryResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TaskRetryResponse
impl Serialize for TaskRetryResponse