pub struct TranslationSubmitItem {
pub document_id: i64,
pub target_locales: Vec<String>,
}Fields
document_id: i64target_locales: Vec<String>Trait Implementations
Sourceimpl Clone for TranslationSubmitItem
impl Clone for TranslationSubmitItem
Sourcefn clone(&self) -> TranslationSubmitItem
fn clone(&self) -> TranslationSubmitItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationSubmitItem
impl ComposeSchema for TranslationSubmitItem
Sourceimpl Debug for TranslationSubmitItem
impl Debug for TranslationSubmitItem
Sourceimpl<'de> Deserialize<'de> for TranslationSubmitItem
impl<'de> Deserialize<'de> for TranslationSubmitItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationSubmitItem
impl JsonSchema for TranslationSubmitItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TranslationSubmitItem
impl Serialize for TranslationSubmitItem