pub struct UpdateTaskMaintenanceSettingsRequest {
pub cleanup_enabled: bool,
pub retention_days: i64,
}Fields
cleanup_enabled: boolretention_days: i64Trait Implementations
Sourceimpl Clone for UpdateTaskMaintenanceSettingsRequest
impl Clone for UpdateTaskMaintenanceSettingsRequest
Sourcefn clone(&self) -> UpdateTaskMaintenanceSettingsRequest
fn clone(&self) -> UpdateTaskMaintenanceSettingsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateTaskMaintenanceSettingsRequest
impl ComposeSchema for UpdateTaskMaintenanceSettingsRequest
Sourceimpl<'de> Deserialize<'de> for UpdateTaskMaintenanceSettingsRequest
impl<'de> Deserialize<'de> for UpdateTaskMaintenanceSettingsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateTaskMaintenanceSettingsRequest
impl JsonSchema for UpdateTaskMaintenanceSettingsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateTaskMaintenanceSettingsRequest
impl RefUnwindSafe for UpdateTaskMaintenanceSettingsRequest
impl Send for UpdateTaskMaintenanceSettingsRequest
impl Sync for UpdateTaskMaintenanceSettingsRequest
impl Unpin for UpdateTaskMaintenanceSettingsRequest
impl UnsafeUnpin for UpdateTaskMaintenanceSettingsRequest
impl UnwindSafe for UpdateTaskMaintenanceSettingsRequest