pub struct GroupTranslationSettingsResponse {
pub enabled: bool,
pub default_target_locales: Vec<String>,
pub source_locale: Option<String>,
pub glossary: Vec<TranslationGlossaryEntry>,
pub queued_count: i64,
pub running_count: i64,
pub succeeded_count: i64,
pub failed_count: i64,
}Fields
enabled: booldefault_target_locales: Vec<String>source_locale: Option<String>glossary: Vec<TranslationGlossaryEntry>queued_count: i64running_count: i64succeeded_count: i64failed_count: i64Trait Implementations
Sourceimpl Clone for GroupTranslationSettingsResponse
impl Clone for GroupTranslationSettingsResponse
Sourcefn clone(&self) -> GroupTranslationSettingsResponse
fn clone(&self) -> GroupTranslationSettingsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GroupTranslationSettingsResponse
impl ComposeSchema for GroupTranslationSettingsResponse
Sourceimpl<'de> Deserialize<'de> for GroupTranslationSettingsResponse
impl<'de> Deserialize<'de> for GroupTranslationSettingsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GroupTranslationSettingsResponse
impl JsonSchema for GroupTranslationSettingsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GroupTranslationSettingsResponse
impl RefUnwindSafe for GroupTranslationSettingsResponse
impl Send for GroupTranslationSettingsResponse
impl Sync for GroupTranslationSettingsResponse
impl Unpin for GroupTranslationSettingsResponse
impl UnsafeUnpin for GroupTranslationSettingsResponse
impl UnwindSafe for GroupTranslationSettingsResponse