pub struct TranslationDirective {
pub source_locale: Option<String>,
pub target_locales: Vec<String>,
}Fields
source_locale: Option<String>target_locales: Vec<String>Trait Implementations
Sourceimpl Clone for TranslationDirective
impl Clone for TranslationDirective
Sourcefn clone(&self) -> TranslationDirective
fn clone(&self) -> TranslationDirective
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationDirective
impl ComposeSchema for TranslationDirective
Sourceimpl Debug for TranslationDirective
impl Debug for TranslationDirective
Sourceimpl Default for TranslationDirective
impl Default for TranslationDirective
Sourcefn default() -> TranslationDirective
fn default() -> TranslationDirective
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TranslationDirective
impl<'de> Deserialize<'de> for TranslationDirective
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TranslationDirective
Sourceimpl JsonSchema for TranslationDirective
impl JsonSchema for TranslationDirective
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TranslationDirective
impl PartialEq for TranslationDirective
Sourceimpl Serialize for TranslationDirective
impl Serialize for TranslationDirective
impl StructuralPartialEq for TranslationDirective