pub struct TranslationJobResponse {Show 13 fields
pub job_id: Uuid,
pub document_id: i64,
pub target_locale: String,
pub source_locale: Option<String>,
pub status: TranslationStatus,
pub provider: Option<TranslationProviderKind>,
pub attempt_count: i32,
pub source_character_count: i64,
pub error_message: Option<String>,
pub created_at: DateTime<Utc>,
pub started_at: Option<DateTime<Utc>>,
pub finished_at: Option<DateTime<Utc>>,
pub updated_at: DateTime<Utc>,
}Fields
job_id: Uuiddocument_id: i64target_locale: Stringsource_locale: Option<String>status: TranslationStatusprovider: Option<TranslationProviderKind>attempt_count: i32source_character_count: i64error_message: Option<String>created_at: DateTime<Utc>started_at: Option<DateTime<Utc>>finished_at: Option<DateTime<Utc>>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for TranslationJobResponse
impl Clone for TranslationJobResponse
Sourcefn clone(&self) -> TranslationJobResponse
fn clone(&self) -> TranslationJobResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationJobResponse
impl ComposeSchema for TranslationJobResponse
Sourceimpl Debug for TranslationJobResponse
impl Debug for TranslationJobResponse
Sourceimpl<'de> Deserialize<'de> for TranslationJobResponse
impl<'de> Deserialize<'de> for TranslationJobResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationJobResponse
impl JsonSchema for TranslationJobResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TranslationJobResponse
impl Serialize for TranslationJobResponse