pub struct TranslationJobsResponse {
pub jobs: Vec<TranslationJobResponse>,
}Fields
jobs: Vec<TranslationJobResponse>Trait Implementations
Sourceimpl Clone for TranslationJobsResponse
impl Clone for TranslationJobsResponse
Sourcefn clone(&self) -> TranslationJobsResponse
fn clone(&self) -> TranslationJobsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationJobsResponse
impl ComposeSchema for TranslationJobsResponse
Sourceimpl Debug for TranslationJobsResponse
impl Debug for TranslationJobsResponse
Sourceimpl<'de> Deserialize<'de> for TranslationJobsResponse
impl<'de> Deserialize<'de> for TranslationJobsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationJobsResponse
impl JsonSchema for TranslationJobsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TranslationJobsResponse
impl Serialize for TranslationJobsResponse