pub struct TranslationProviderInput {
pub provider: TranslationProviderKind,
pub enabled: bool,
pub priority: i32,
pub endpoint: Option<String>,
pub api_key: Option<String>,
pub model: Option<String>,
pub llm_api_kind: Option<TranslationLlmApiKind>,
pub deepl_plan: Option<DeeplPlan>,
pub monthly_character_limit: Option<i64>,
}Fields
provider: TranslationProviderKindenabled: boolpriority: i32endpoint: Option<String>api_key: Option<String>model: Option<String>llm_api_kind: Option<TranslationLlmApiKind>deepl_plan: Option<DeeplPlan>monthly_character_limit: Option<i64>Trait Implementations
Sourceimpl Clone for TranslationProviderInput
impl Clone for TranslationProviderInput
Sourcefn clone(&self) -> TranslationProviderInput
fn clone(&self) -> TranslationProviderInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationProviderInput
impl ComposeSchema for TranslationProviderInput
Sourceimpl Debug for TranslationProviderInput
impl Debug for TranslationProviderInput
Sourceimpl<'de> Deserialize<'de> for TranslationProviderInput
impl<'de> Deserialize<'de> for TranslationProviderInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationProviderInput
impl JsonSchema for TranslationProviderInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TranslationProviderInput
impl Serialize for TranslationProviderInput