pub struct TranslationProviderResponse {
pub provider: TranslationProviderKind,
pub enabled: bool,
pub priority: i32,
pub endpoint: Option<String>,
pub has_api_key: bool,
pub model: Option<String>,
pub llm_api_kind: Option<TranslationLlmApiKind>,
pub deepl_plan: Option<DeeplPlan>,
pub monthly_character_limit: Option<i64>,
pub current_month_characters: i64,
}Fields
provider: TranslationProviderKindenabled: boolpriority: i32endpoint: Option<String>has_api_key: boolmodel: Option<String>llm_api_kind: Option<TranslationLlmApiKind>deepl_plan: Option<DeeplPlan>monthly_character_limit: Option<i64>current_month_characters: i64Trait Implementations
Sourceimpl Clone for TranslationProviderResponse
impl Clone for TranslationProviderResponse
Sourcefn clone(&self) -> TranslationProviderResponse
fn clone(&self) -> TranslationProviderResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationProviderResponse
impl ComposeSchema for TranslationProviderResponse
Sourceimpl Debug for TranslationProviderResponse
impl Debug for TranslationProviderResponse
Sourceimpl<'de> Deserialize<'de> for TranslationProviderResponse
impl<'de> Deserialize<'de> for TranslationProviderResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationProviderResponse
impl JsonSchema for TranslationProviderResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TranslationProviderResponse
impl RefUnwindSafe for TranslationProviderResponse
impl Send for TranslationProviderResponse
impl Sync for TranslationProviderResponse
impl Unpin for TranslationProviderResponse
impl UnsafeUnpin for TranslationProviderResponse
impl UnwindSafe for TranslationProviderResponse