pub struct TranslationSettingsResponse {
pub providers: Vec<TranslationProviderResponse>,
}Fields
providers: Vec<TranslationProviderResponse>Trait Implementations
Sourceimpl Clone for TranslationSettingsResponse
impl Clone for TranslationSettingsResponse
Sourcefn clone(&self) -> TranslationSettingsResponse
fn clone(&self) -> TranslationSettingsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for TranslationSettingsResponse
impl ComposeSchema for TranslationSettingsResponse
Sourceimpl Debug for TranslationSettingsResponse
impl Debug for TranslationSettingsResponse
Sourceimpl<'de> Deserialize<'de> for TranslationSettingsResponse
impl<'de> Deserialize<'de> for TranslationSettingsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationSettingsResponse
impl JsonSchema for TranslationSettingsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TranslationSettingsResponse
impl RefUnwindSafe for TranslationSettingsResponse
impl Send for TranslationSettingsResponse
impl Sync for TranslationSettingsResponse
impl Unpin for TranslationSettingsResponse
impl UnsafeUnpin for TranslationSettingsResponse
impl UnwindSafe for TranslationSettingsResponse