pub struct UpdateGroupTranslationSettingsRequest {
pub enabled: bool,
pub default_target_locales: Vec<String>,
pub source_locale: Option<String>,
pub glossary: Vec<TranslationGlossaryEntry>,
}Fields
enabled: booldefault_target_locales: Vec<String>source_locale: Option<String>glossary: Vec<TranslationGlossaryEntry>Trait Implementations
Sourceimpl Clone for UpdateGroupTranslationSettingsRequest
impl Clone for UpdateGroupTranslationSettingsRequest
Sourcefn clone(&self) -> UpdateGroupTranslationSettingsRequest
fn clone(&self) -> UpdateGroupTranslationSettingsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateGroupTranslationSettingsRequest
impl ComposeSchema for UpdateGroupTranslationSettingsRequest
Sourceimpl<'de> Deserialize<'de> for UpdateGroupTranslationSettingsRequest
impl<'de> Deserialize<'de> for UpdateGroupTranslationSettingsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateGroupTranslationSettingsRequest
impl JsonSchema for UpdateGroupTranslationSettingsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateGroupTranslationSettingsRequest
impl RefUnwindSafe for UpdateGroupTranslationSettingsRequest
impl Send for UpdateGroupTranslationSettingsRequest
impl Sync for UpdateGroupTranslationSettingsRequest
impl Unpin for UpdateGroupTranslationSettingsRequest
impl UnsafeUnpin for UpdateGroupTranslationSettingsRequest
impl UnwindSafe for UpdateGroupTranslationSettingsRequest