pub struct UpdateTranslationSettingsRequest {
pub providers: Vec<TranslationProviderInput>,
}Fields
providers: Vec<TranslationProviderInput>Trait Implementations
Sourceimpl Clone for UpdateTranslationSettingsRequest
impl Clone for UpdateTranslationSettingsRequest
Sourcefn clone(&self) -> UpdateTranslationSettingsRequest
fn clone(&self) -> UpdateTranslationSettingsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateTranslationSettingsRequest
impl ComposeSchema for UpdateTranslationSettingsRequest
Sourceimpl<'de> Deserialize<'de> for UpdateTranslationSettingsRequest
impl<'de> Deserialize<'de> for UpdateTranslationSettingsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateTranslationSettingsRequest
impl JsonSchema for UpdateTranslationSettingsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateTranslationSettingsRequest
impl RefUnwindSafe for UpdateTranslationSettingsRequest
impl Send for UpdateTranslationSettingsRequest
impl Sync for UpdateTranslationSettingsRequest
impl Unpin for UpdateTranslationSettingsRequest
impl UnsafeUnpin for UpdateTranslationSettingsRequest
impl UnwindSafe for UpdateTranslationSettingsRequest